const app = require('../../utils/util.js');
const tools = require('../../utils/tools.js');
Page({
  data: {
    url: '', //直播地址
    title: '', //直播课名字
    message: '', //直播课信息
    playTimes: 0, //多少人在看（播放次数）
    id: 0, //带过来的id
    socketOpen: false, //socket打开状态
    chatContent: [], //聊天内容
    inputValue: '', //我输入的话
    bottom: "", //滑到底状态 防止弹出消息不跳到最后一条
    pushUrl: '', //我的推流地址
    videoContext: '', //绑定pusher
    fullScreenFlag: false, //全屏状态
    livectx: "", //绑定player
    spfx: "vertical",
    spfx1: "vertical",
    isHands: false, //是否举手状态
    timeoutObj: null, //心跳定时
    _timeout: 5000, //5秒发送一次心跳
    isCloseStatus: false //关闭状态
  },
  // socket状态改变
  statechange: function (e) {
    console.log(e)
  },
  // 滑动聊天室
  scrollToTop() {
    this.setAction({
      scrollTop: 0
    })
  },
  // 绑定输入的话
  bindKeyInput: function (e) {
    this.setData({
      inputValue: e.detail.value
    })
  },
  // 点击举手
  hands() {
    console.log("我点击举手了")
    this.sendSocketMessage("put up hands")
  },
  // 提交我说的话
  submit: function () {
    let input_val = this.data.inputValue;
    this.sendSocketMessage(input_val)
    this.setData({
      inputValue: ''
    })
  },
  // 全屏执行
  fullScreen: function () {
    let fullScreenFlag = this.data.fullScreenFlag;
    if (fullScreenFlag) {
      fullScreenFlag = false;
    } else {
      fullScreenFlag = true;
    }
    if (fullScreenFlag) {
      //全屏
      this.data.livectx.requestFullScreen({
        success: () => {
          this.setData({
            fullScreenFlag: fullScreenFlag,
            spfx: "horizontal",
            spfx1: "horizontal"
          });
          if (this.data.isHands == true) {
            this.setData({
              isHands: false
            })
            this.setData({
              isHands: true
            })
          }
          console.log('我要全屏执行了');
        },
        fail: () => {
          console.log('我要全屏执行失败了');
        }
      });
    } else {
      //缩小
      this.data.livectx.exitFullScreen({
        success: () => {
          console.log('fullscreen success');
          this.setData({
            fullScreenFlag: fullScreenFlag,
            spfx: "vertical",
            spfx1: "vertical"
          });
        },
        fail: () => {
          console.log('exit fullscreen success');
        }
      });
    }
  },
  // 获取直播信息
  getZbArr(sessionKey) {
    wx.request({
      url: app.globalData.publicUrl + '/wx/course/selectLiveByCourseId',
      method: "post",
      data: {
        sessionKey: sessionKey,
        courseId: this.data.id
      },
      success: (e) => {
        console.log(e, "11111111111111111")
        this.setData({
          url: e.data.pullUrl.flvUrl,
          // url: e.data.pullUrl.rtmpUrl,
          title: e.data.course.courseName,
          message: e.data.course.courseInfo,
          playTimes: e.data.course.playTimes
        })
      }
    })
  },
  // socket连接
  socketConnect(sessionKey) {
    let newSessionkey = encodeURIComponent(sessionKey);
    wx.connectSocket({
      url: app.globalData.publicSocketUrl + '/live/socket?sessionkey=' + newSessionkey + "&courseId=" + this.data.id
    })
    wx.onSocketOpen(() => {
      console.log("我连上啦")
      this.setData({
        socketOpen: true
      })
      this.setData({
        timeoutObj: setInterval(() => {
          this.startHeart(sessionKey)
        }, this.data._timeout)
      })
    })
    wx.onSocketError(function () {
      console.log("我连接出错了")
    })
    wx.onSocketClose(function () {
      console.log("我关了")
    })
    wx.onSocketMessage((data) => {
      console.log(data, "2222222222222")
      let res = JSON.parse(data.data);
      if (res.msg == "HeartBeat") {
        return false;
      }
      if (res.messageType == "message" || res.messageType == "system") {
        this.setData({
          chatContent: this.data.chatContent.concat(res),
          bottom: 'scrollBottom'
        })
      }
      if (res.msg == "socketLiveEnd") {
        this.setData({
          url: "",
        })
        if (this.data.socketOpen) {
          wx.closeSocket()
        }
        this.data.videoContext.stop()
        wx.showModal({
          showCancel: false,
          content: "直播结束了",
          success(res) {
            if (res.confirm) {
              wx.switchTab({
                url: '../index/index'
              })
            }
          }
        })
      }
      if (res.messageType == "studentPushStream") {
        console.log(res, "我收到了举手的推流")
        this.data.videoContext.start();
        this.setData({
          isHands: true,
          pushUrl: res.pushUrl
        })
      }
      if (res.messageType == "stopStudentPushStream") {
        console.log(res.pushUrl, "不推了")
        this.data.videoContext.stop()
        this.setData({
          isHands: false,
          pushUrl: ""
        })
      }
    })
  },
  // 发送消息
  sendSocketMessage(msg) {
    if (this.data.socketOpen) {
      wx.sendSocketMessage({
        data: msg
      })
    }
  },
  // 心跳
  startHeart(sessionKey) {
    wx.sendSocketMessage({
      data: "HeartBeat",
      success: (res) => {
        console.log(res, "发送心跳成功")
      },
      fail: (err) => {
        console.log(err, "发送心跳失败")
        if (this.data.isCloseStatus == false) {
          wx.closeSocket();
          clearInterval(this.data.timeoutObj);
          this.socketConnect(sessionKey);
        } else {
          clearInterval(this.data.timeoutObj);
        }
      }
    })
  },
  async onShow() {
    const sessionKey = await tools.checkSessionAndLogin();
    this.socketConnect(sessionKey);
  },
  onHide() {
    this.setData({
      isCloseStatus: true
    })
    if (this.data.socketOpen) {
      wx.closeSocket()
    }
    clearInterval(this.data.timeoutObj);
    this.data.videoContext.stop()
  },
  onUnload() {
    this.setData({
      isCloseStatus: true
    })
    if (this.data.socketOpen) {
      wx.closeSocket()
    }
    clearInterval(this.data.timeoutObj);
    this.data.videoContext.stop()
  },
  async onLoad(options) {
    this.setData({
      id: options.id,
      videoContext: wx.createLivePusherContext("video-livePusher"),
      livectx: wx.createLivePlayerContext('livectx')
    })
    const sessionKey = await tools.checkSessionAndLogin();
    this.getZbArr(sessionKey);
  }
})